import { Component, OnInit, ViewEncapsulation, ViewChild } from '@angular/core';
import { extend,isNullOrUndefined } from '@syncfusion/ej2-base';
import {
  PopupOpenEventArgs, ScheduleComponent, MonthService, DayService, WeekService, WorkWeekService,GroupModel,
  EventSettingsModel, AgendaService, MonthAgendaService, CurrentAction
} from '@syncfusion/ej2-angular-schedule';


    
@Component({
  selector: 'app-root',
  templateUrl: './app.component.html',
  styleUrls: ['./app.component.css'],
  providers: [WeekService,WorkWeekService, MonthService, DayService,AgendaService],
  encapsulation: ViewEncapsulation.None
})

export class AppComponent implements OnInit {
  @ViewChild('scheduleObj',{static:true}) scheduleObj: ScheduleComponent;

  title = 'editor-customization';
    public resourceDataSource: Object[] = [
        { Text: 'Margaret', Id: 1, Color: '#1aaa55' },
        { Text: 'Robert', Id: 2, Color: '#357cd2' },
        { Text: 'Laura', Id: 3, Color: '#7fa900' },
       
    ];
    public group: GroupModel = { allowGroupEdit: true, resources: ['Conferences'] };
    public allowMultiple: Boolean = true;

  public statusFields: Object = { text: 'StatusText', value: 'StatusText' };
  public fields: Object ={ text:'Text', value:'Id'}
  public StatusData: Object[] = [
    { StatusText: 'New', Id: 1 },
    { StatusText: 'Requested', Id: 2 },
    { StatusText: 'Confirmed', Id: 3 }
  ];
 public data: Object[] = [
      {
        Id: 1,
        Subject: 'Board Meeting',
        Description: 'Meeting to discuss business goal of 2018.',
        StartTime: new Date(2018, 6, 30, 9, 0),
        EndTime: new Date(2018, 6, 30, 11, 0),
        ConferenceId: 1,
        details: [{
          OrderID: 1,
          CustomerName: 'Chai',
          OrderDate: new Date()
        }]
      },
      {
        Id: 2,
        Subject: 'Training session on JSP',
        Description: 'Knowledge sharing on JSP topics.',
        StartTime: new Date(2018, 6, 30, 15, 0),
        EndTime: new Date(2018, 6, 30, 17, 0),
        ConferenceId: 2,
        details: [{
          OrderID: 2,
          CustomerName: 'Nancy',
          OrderDate: new Date()
        }]

      },
      {
        Id: 3,
        Subject: 'Sprint Planning with Team members',
        Description: 'Planning tasks for sprint.',
        StartTime: new Date(2018, 6, 30, 9, 30),
        EndTime: new Date(2018, 6, 30, 11, 0),
        ConferenceId: 3,
        details: [{
          OrderID: 1,
          CustomerName: 'Nancy',
          OrderDate: new Date()
        },{
          OrderID: 2,
          CustomerName: 'Chai',
          OrderDate: new Date()
        }]

      }];
  public eventData: EventSettingsModel = { dataSource: this.data,fields: {
    subject: { name: 'Subject', validation: { required: true } }} };
  public setDate: Date = new Date(2018, 6, 30);
  public selectedDate: Date = new Date(2019, 3, 1);
  private selectionTarget: Element;
  public dateParser(data: string) {
    return new Date(data);
  }
  public check(data:any){
    if(!isNullOrUndefined(data.groupIndex)){
    return this.scheduleObj.getResourcesByIndex(data.groupIndex).resourceData.Id;
    }else {
      return data.ConferenceId
    }
  
  }
  public onPopupOpen(args: PopupOpenEventArgs): void {
    this.selectionTarget = null;
    this.selectionTarget = args.target;
}
public onDetailsClick(): void {
    this.onCloseClick();
    const data: Object = this.scheduleObj.getCellDetails(this.scheduleObj.getSelectedElements()) as Object;
    this.scheduleObj.openEditor(data, 'Add');
}
public onAddClick(): void {
    this.onCloseClick();
    const data: Object = this.scheduleObj.getCellDetails(this.scheduleObj.getSelectedElements()) as Object;
    const eventData: { [key: string]: Object } = this.scheduleObj.eventWindow.getObjectFromFormData('e-quick-popup-wrapper');
    this.scheduleObj.eventWindow.convertToEventData(data as { [key: string]: Object }, eventData);
    eventData.Id = this.scheduleObj.eventBase.getEventMaxID() as number + 1;
    this.scheduleObj.addEvent(eventData);
}
public onEditClick(args: any): void {
    if (this.selectionTarget) {
    let eventData: { [key: string]: Object } = this.scheduleObj.getEventDetails(this.selectionTarget) as { [key: string]: Object };
    let currentAction: CurrentAction = 'Save';
    if (!isNullOrUndefined(eventData.RecurrenceRule) && eventData.RecurrenceRule !== '') {
        if (args.target.classList.contains('e-edit-series')) {
        currentAction = 'EditSeries';
        eventData = this.scheduleObj.eventBase.getRecurrenceEvent(eventData);
        } else {
        currentAction = 'EditOccurrence';
        }
    }
    this.scheduleObj.openEditor(eventData, currentAction);
    }
}
public onDeleteClick(args: any): void {
    this.onCloseClick();
    if (this.selectionTarget) {
    const eventData: { [key: string]: Object } = this.scheduleObj.getEventDetails(this.selectionTarget) as { [key: string]: Object };
    let currentAction: CurrentAction;
    if (!isNullOrUndefined(eventData.RecurrenceRule) && eventData.RecurrenceRule !== '') {
        currentAction = args.target.classList.contains('e-delete-series') ? 'DeleteSeries' : 'DeleteOccurrence';
    }
    this.scheduleObj.deleteEvent(eventData, currentAction);
    }
}
public onCloseClick(): void {
    this.scheduleObj.quickPopup.quickPopupHide();
}
  constructor() { }

  ngOnInit() {
  }

}
